[java-idp-plugin-duo] branch dev/JDUO-80 updated: Add setter for passwordless context lookup and adjust some javadocs.

Scott Cantor cantor.2 at osu.edu
Thu Jan 4 15:20:59 UTC 2024


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch dev/JDUO-80
in repository java-idp-plugin-duo.

View the commit online:
http://git.shibboleth.net/view/?p=java-idp-plugin-duo.git;a=commit;h=f3dff26f7f0bf509a053b9bd6b3b9d4f58495093

The following commit(s) were added to refs/heads/dev/JDUO-80 by this push:
     new f3dff26f Add setter for passwordless context lookup and adjust some javadocs.
f3dff26f is described below

commit f3dff26f7f0bf509a053b9bd6b3b9d4f58495093
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Thu Jan 4 10:20:54 2024 -0500

    Add setter for passwordless context lookup and adjust some javadocs.
---
 .../duo/impl/PopulateDuoAuthenticationContext.java | 25 ++++++++++++++++++----
 1 file changed, 21 insertions(+), 4 deletions(-)

diff --git a/idp-duo-impl/src/main/java/net/shibboleth/idp/plugin/authn/duo/impl/PopulateDuoAuthenticationContext.java b/idp-duo-impl/src/main/java/net/shibboleth/idp/plugin/authn/duo/impl/PopulateDuoAuthenticationContext.java
index 917e9ef4..e7651698 100644
--- a/idp-duo-impl/src/main/java/net/shibboleth/idp/plugin/authn/duo/impl/PopulateDuoAuthenticationContext.java
+++ b/idp-duo-impl/src/main/java/net/shibboleth/idp/plugin/authn/duo/impl/PopulateDuoAuthenticationContext.java
@@ -144,9 +144,9 @@ public class PopulateDuoAuthenticationContext extends AbstractAuthenticationActi
     }
     
     /**
-     * Set the strategy used to locate the {@link DuoOIDCAuthenticationContext} to operate on.
+     * Set the strategy used to create/locate the {@link DuoOIDCAuthenticationContext} to operate on.
      * 
-     * @param strategy lookup strategy
+     * @param strategy creation strategy
      */
     public void setDuoContextCreationStrategy(
             @Nonnull final Function<ProfileRequestContext,DuoOIDCAuthenticationContext> strategy) {
@@ -155,9 +155,24 @@ public class PopulateDuoAuthenticationContext extends AbstractAuthenticationActi
         duoAuthContextCreationStrategy = Constraint.isNotNull(strategy, "DuoAuthenticationContext"
                 + " creation strategy cannot be null");
     }
+    
+    /**
+     * Set the strategy used to locate the {@link DuoPasswordlessContext} to operate on.
+     * 
+     * @param strategy lookup strategy
+     * 
+     * @since 2.1.0
+     */
+    public void setPasswordlessContextLookupStrategy(
+            @Nonnull final Function<ProfileRequestContext,DuoPasswordlessContext> strategy) {
+        checkSetterPreconditions();
 
+        passwordlessContextLookupStrategy = Constraint.isNotNull(strategy, "DuoPasswordlessContext"
+                + " lookup strategy cannot be null");
+    }
+    
     /**
-     * Set DuoIntegration lookup strategy to use.
+     * Set standard DuoIntegration lookup strategy to use.
      * 
      * @param strategy lookup strategy
      */
@@ -170,9 +185,11 @@ public class PopulateDuoAuthenticationContext extends AbstractAuthenticationActi
     }
 
     /**
      * Set DuoIntegration lookup strategy to use.
      * 
      * @param strategy lookup strategy
+     * 
+     * @since 2.1.0
      */
     public void setPasswordlessDuoIntegrationLookupStrategy(
             @Nonnull final Function<ProfileRequestContext, DuoOIDCIntegration> strategy) {
@@ -170,9 +185,11 @@ public class PopulateDuoAuthenticationContext extends AbstractAuthenticationActi
 
     /**
-     * Set DuoIntegration lookup strategy to use.
+     * Set passwordless DuoIntegration lookup strategy to use.
      * 
      * @param strategy lookup strategy

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list